Index: chrome/test/ispy/client/boto_bucket.py |
diff --git a/chrome/test/ispy/client/boto_bucket.py b/chrome/test/ispy/client/boto_bucket.py |
index 139d83c4df857d4b588d62b9f76aa57fb24c7142..ce963bc3d6b2ea32020e6ed7bf5df82aeb3de066 100644 |
--- a/chrome/test/ispy/client/boto_bucket.py |
+++ b/chrome/test/ispy/client/boto_bucket.py |
@@ -7,9 +7,9 @@ import os |
import sys |
# boto requires depot_tools/third_party be in the path. Use |
# src/tools/find_depot_tools.py to add this directory. |
sys.path.append(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir, |
- os.pardir, os.pardir, 'tools')) |
+ os.pardir, os.pardir, 'build')) |
import find_depot_tools |
DEPOT_TOOLS_PATH = find_depot_tools.add_depot_tools_to_path() |
sys.path.append(os.path.join(os.path.abspath(DEPOT_TOOLS_PATH), 'third_party')) |
@@ -45,7 +45,7 @@ class BotoCloudBucket(cloud_bucket.BaseCloudBucket): |
key.set_contents_from_string(contents) |
# Open permissions for the appengine account to read/write. |
key.add_email_grant('FULL_CONTROL', |
- 'ispy.google.com@appspot.gserviceaccount.com') |
+ 'ispy.google.com@appspot.gserviceaccount.com') |
# override |
def DownloadFile(self, path): |
@@ -7,9 +7,9 @@ import os |
import sys |
# boto requires depot_tools/third_party be in the path. Use |
-# src/tools/find_depot_tools.py to add this directory. |
+# src/build/find_depot_tools.py to add this directory. |
sys.path.append(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir, |